#! /usr/bin/env ruby

require 'base64'
require 'json'
require 'rest_client'
require 'pp'

module WTBuildHelpers
    module TeamCity
        def self.fetch_commit_range(teamcity_url, build_type_id, username, password)

            auth = "#{username}:#{password}"
            auth_token = Base64.strict_encode64(auth)

            headers = { "Authorization" => "Basic #{auth_token}",
                        "Accept" => "application/json" 
                      }
            full_url = "#{teamcity_url}/app/rest/buildTypes/id:#{build_type_id}/builds/status:SUCCESS"

            begin
                response = RestClient.get(full_url, headers=headers)
                json_response = JSON.parse(response.body)
            rescue RestClient::Exception => e 
                pp e
                exit
            end

            start_revision = ENV["BUILD_VCS_NUMBER"]
            end_revision = json_response["revisions"]["revision"][0]["version"]
            
            puts "##teamcity[setParameter name='env.TEAMCITY_COMMIT_RANGE' value='#{end_revision}..#{start_revision}']" 
        end
    end
end

if __FILE__ == $0
    if ARGV.length < 4
        puts "Usage: teamcity_git_range_fetch.rb [TeamCity Url] [TeamCity Build Type Id] [TeamCity User Name] [TeamCity Password]"
        puts "These parameters can be passed from TeamCity with the following line: "
        puts "    teamcity_git_range_fetch.rb \"%teamcity.serverUrl%\" \"%system.teamcity.buildType.id%\" \"%system.teamcity.auth.userId%\" \"%system.teamcity.auth.password%\""
        
        exit
    end

    WTBuildHelpers::TeamCity.fetch_commit_range(ARGV[0], ARGV[1], ARGV[2], ARGV[3])
end